==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/lv-LV/localizations.php <==
<?php

return [

    'select_language' => 'Izvēlieties valodu',
    'languages' => [
        'en-US'=> 'Angļu, ASV',
        'en-GB'=> 'Angļu, UK',
        'am-ET' => 'Amharu',
        'af-ZA'=> 'Āfrikāņu',
        'ar-SA'=> 'Arābu',
        'bg-BG'=> 'Bulgāru',
        'zh-CN'=> 'Ķīniešu Vienkāršota',
        'zh-TW'=> 'Ķīniešu Tradicionāla',
        'ca-ES' => 'Kataloniešu',
        'hr-HR'=> 'Horvātu',
        'cs-CZ'=> 'Čehu',
        'da-DK'=> 'Dāņu',
        'nl-NL'=> 'Nīderlandiešu',
        'en-ID'=> 'Angļu, Indonēzija',
        'et-EE'=> 'Igauņu',
        'fil-PH'=> 'Filipīniešu',
        'fi-FI'=> 'Somu',
        'fr-FR'=> 'Franču',
        'de-DE'=> 'Vācu',
        'de-if'=> 'Vācu (neformāls)',
        'el-GR'=> 'Grieķu',
        'he-IL'=> 'Ebreju',
        'hu-HU'=> 'Ungāru',
        'is-IS' => 'Islandiešu',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Īru',
        'it-IT'=> 'Itāļu',
        'ja-JP'=> 'Japāņu',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Korejiešu',
        'lt-LT'=>'Lietuviešu',
        'lv-LV'=> 'Latviešu',
        'mk-MK'=> 'Macedonian',
        'ms-MY'=> 'Malay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolian',
        'no-NO'=> 'Norwegian',
        'fa-IR'=> 'Persian',
        'pl-PL'=> 'Polish',
        'pt-PT'=> 'Portuguese',
        'pt-BR'=> 'Portuguese, Brazilian',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Krievu',
        'sr-CS' => 'Serbu (Latīņu)',
        'sk-SK'=> 'Slovāku',
        'sl-SI'=> 'Slovēņu',
        'so-SO'=> 'Somāļu',
        'es-ES'=> 'Spāņu',
        'es-CO'=> 'Spāņu, Kolubija',
        'es-MX'=> 'Spanish, Mexico',
        'es-VE'=> 'Spanish, Venezuela',
        'sv-SE'=> 'Swedish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turkish',
        'uk-UA'=> 'Ukranian',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a country',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'United Arab Emirates',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua And Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'American Samoa',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'Azerbaijan',
        'BA'=>'Bosnia And Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Island',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Cocos (Keeling) Islands',
        'CD'=>'Congo (Democratic Republic)',
        'CF'=>'Central African Republic',
        'CG'=>'Congo (Republic)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Cook Islands',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'People\'s Republic of China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Cyprus',
        'CZ'=>'Czech Republic',
        'DE'=>'Germany',
        'DJ'=>'Djibouti',
        'DK'=>'Denmark',
        'DM'=>'Dominica',
        'DO'=>'Dominican Republic',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egypt',
        'ER'=>'Eritrea',
        'ES'=>'Spain',
        'ET'=>'Ethiopia',
        'EU'=>'European Union',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Islands (Malvinas)',
        'FM'=>'Micronesia, Federated States Of',
        'FO'=>'Faroe Islands',
        'FR'=>'France',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'French Guiana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard And Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (local name: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'India',
        'IO'=>'British Indian Ocean Territory',
        'IQ'=>'Iraq',
        'IR'=>'Iran, Islamic Republic Of',
        'IS'=>'Iceland',
        'IT'=>'Italy',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Comoros',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'Korea, Republic Of',
        'KW'=>'Kuwait',
        'KY'=>'Cayman Islands',
        'KZ'=>'Kazakhstan',
        'LA'=>'Lao People\'s Democratic Republic',
        'LB'=>'Lebanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Republic Of',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Islands',
        'MK'=>'Macedonia, The Former Yugoslav Republic Of',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'UK'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'South Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'United Kingdom',
        'US'=>'United States',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lv-LV/localizations.php <==
<?php

return [

    'select_language' => 'Select a Language',
    'languages' => [
        'en-US'=> 'Angļu, ASV',
        'en-GB'=> 'Angļu, UK',
        'am-ET' => 'Amharu',
        'af-ZA'=> 'Āfrikāņu',
        'ar-SA'=> 'Arābu',
        'bg-BG'=> 'Bulgāru',
        'zh-CN'=> 'Ķīniešu Vienkāršota',
        'zh-TW'=> 'Ķīniešu Tradicionāla',
        'ca-ES' => 'Kataloniešu',
        'hr-HR'=> 'Horvātu',
        'cs-CZ'=> 'Čehu',
        'da-DK'=> 'Dāņu',
        'nl-NL'=> 'Nīderlandiešu',
        'en-ID'=> 'Angļu, Indonēzija',
        'et-EE'=> 'Igauņu',
        'fil-PH'=> 'Filipīniešu',
        'fi-FI'=> 'Somu',
        'fr-FR'=> 'Franču',
        'de-DE'=> 'Vācu',
        'de-if'=> 'Vācu (neformāls)',
        'el-GR'=> 'Grieķu',
        'he-IL'=> 'Ebreju',
        'hu-HU'=> 'Ungāru',
        'is-IS' => 'Islandiešu',
        'id-ID'=> 'Indonesian',
        'ga-IE'=> 'Īru',
        'it-IT'=> 'Itāļu',
        'ja-JP'=> 'Japāņu',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Korejiešu',
        'lt-LT'=>'Lietuviešu',
        'lv-LV'=> 'Latviešu',
        'mk-MK'=> 'Macedonian',
        'ms-MY'=> 'Malay',
        'mi-NZ'=> 'Maori',
        'mn-MN'=> 'Mongolian',
        //'no-NO'=> 'Norwegian',
        'nb-NO'=> 'Norwegian Bokmål',
        //'nn-NO'=> 'Norwegian Nynorsk',
        'fa-IR'=> 'Persian',
        'pl-PL'=> 'Polish',
        'pt-PT'=> 'Portuguese',
        'pt-BR'=> 'Portuguese, Brazilian',
        'ro-RO'=> 'Romanian',
        'ru-RU'=> 'Krievu',
        'sr-CS' => 'Serbu (Latīņu)',
        'sk-SK'=> 'Slovāku',
        'sl-SI'=> 'Slovēņu',
        'so-SO'=> 'Somāļu',
        'es-ES'=> 'Spāņu',
        'es-CO'=> 'Spāņu, Kolubija',
        'es-MX'=> 'Spanish, Mexico',
        'es-VE'=> 'Spanish, Venezuela',
        'sv-SE'=> 'Swedish',
        'tl-PH'=> 'Tagalog',
        'ta-IN'=> 'Tamil',
        'th-TH'=> 'Thai',
        'tr-TR'=> 'Turkish',
        'uk-UA'=> 'Ukranian',
        'vi-VN'=> 'Vietnamese',
        'cy-GB'=> 'Welsh',
        'zu-ZA'=> 'Zulu',
    ],

    'select_country' => 'Select a Country',
    
    'countries' => [
        'AC'=>'Ascension Island',
        'AD'=>'Andorra',
        'AE'=>'United Arab Emirates',
        'AF'=>'Afghanistan',
        'AG'=>'Antigua And Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Albania',
        'AM'=>'Armenia',
        'AN'=>'Netherlands Antilles',
        'AO'=>'Angola',
        'AQ'=>'Antarctica',
        'AR'=>'Argentina',
        'AS'=>'American Samoa',
        'AT'=>'Austria',
        'AU'=>'Australia',
        'AW'=>'Aruba',
        'AX'=>'Ãƒâ€¦land',
        'AZ'=>'Azerbaijan',
        'BA'=>'Bosnia And Herzegovina',
        'BB'=>'Barbados',
        'BE'=>'Belgium',
        'BD'=>'Bangladesh',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaria',
        'BH'=>'Bahrain',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Darussalam',
        'BO'=>'Bolivia',
        'BR'=>'Brazil',
        'BS'=>'Bahamas',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Island',
        'BW'=>'Botswana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Canada',
        'CC'=>'Cocos (Keeling) Islands',
        'CD'=>'Congo (Democratic Republic)',
        'CF'=>'Central African Republic',
        'CG'=>'Congo (Republic)',
        'CH'=>'Switzerland',
        'CI'=>'Côte d\'Ivoire',
        'CK'=>'Cook Islands',
        'CL'=>'Chile',
        'CM'=>'Cameroon',
        'CN'=>'People\'s Republic of China',
        'CO'=>'Colombia',
        'CR'=>'Costa Rica',
        'CU'=>'Cuba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Island',
        'CY'=>'Cyprus',
        'CZ'=>'Czech Republic',
        'DE'=>'Germany',
        'DJ'=>'Djibouti',
        'DK'=>'Denmark',
        'DM'=>'Dominica',
        'DO'=>'Dominican Republic',
        'DZ'=>'Algeria',
        'EC'=>'Ecuador',
        'EE'=>'Estonia',
        'EG'=>'Egypt',
        'GB-ENG'=>'England',
        'ER'=>'Eritrea',
        'ES'=>'Spain',
        'ET'=>'Ethiopia',
        'EU'=>'European Union',
        'FI'=>'Finland',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Islands (Malvinas)',
        'FM'=>'Micronesia, Federated States Of',
        'FO'=>'Faroe Islands',
        'FR'=>'France',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Georgia',
        'GF'=>'French Guiana',
        'GG'=>'Guernsey',
        'GH'=>'Ghana',
        'GI'=>'Gibraltar',
        'GL'=>'Greenland',
        'GM'=>'Gambia',
        'GN'=>'Guinea',
        'GP'=>'Guadeloupe',
        'GQ'=>'Equatorial Guinea',
        'GR'=>'Greece',
        'GS'=>'South Georgia And The South Sandwich Islands',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Guinea-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard And Mc Donald Islands',
        'HN'=>'Honduras',
        'HR'=>'Croatia (local name: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Hungary',
        'ID'=>'Indonesia',
        'IE'=>'Ireland',
        'IL'=>'Israel',
        'IM'=>'Isle of Man',
        'IN'=>'India',
        'IO'=>'British Indian Ocean Territory',
        'IQ'=>'Iraq',
        'IR'=>'Iran, Islamic Republic Of',
        'IS'=>'Iceland',
        'IT'=>'Italy',
        'JE'=>'Jersey',
        'JM'=>'Jamaica',
        'JO'=>'Jordan',
        'JP'=>'Japan',
        'KE'=>'Kenya',
        'KG'=>'Kyrgyzstan',
        'KH'=>'Cambodia',
        'KI'=>'Kiribati',
        'KM'=>'Comoros',
        'KN'=>'Saint Kitts And Nevis',
        'KR'=>'Korea, Republic Of',
        'KW'=>'Kuwait',
        'KY'=>'Cayman Islands',
        'KZ'=>'Kazakhstan',
        'LA'=>'Lao People\'s Democratic Republic',
        'LB'=>'Lebanon',
        'LC'=>'Saint Lucia',
        'LI'=>'Liechtenstein',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberia',
        'LS'=>'Lesotho',
        'LT'=>'Lithuania',
        'LU'=>'Luxembourg',
        'LV'=>'Latvia',
        'LY'=>'Libyan Arab Jamahiriya',
        'MA'=>'Morocco',
        'MC'=>'Monaco',
        'MD'=>'Moldova, Republic Of',
        'ME'=>'Montenegro',
        'MG'=>'Madagascar',
        'MH'=>'Marshall Islands',
        'MK'=>'Macedonia, The Former Yugoslav Republic Of',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Mongolia',
        'MO'=>'Macau',
        'MP'=>'Northern Mariana Islands',
        'MQ'=>'Martinique',
        'MR'=>'Mauritania',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldives',
        'MW'=>'Malawi',
        'MX'=>'Mexico',
        'MY'=>'Malaysia',
        'MZ'=>'Mozambique',
        'NA'=>'Namibia',
        'NC'=>'New Caledonia',
        'NE'=>'Niger',
        'NF'=>'Norfolk Island',
        'NG'=>'Nigeria',
        'NI'=>'Nicaragua',
        'NL'=>'Netherlands',
        'GB-NIR' => 'Northern Ireland',
        'NO'=>'Norway',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'New Zealand',
        'OM'=>'Oman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'French Polynesia',
        'PG'=>'Papua New Guinea',
        'PH'=>'Philippines, Republic of the',
        'PK'=>'Pakistan',
        'PL'=>'Poland',
        'PM'=>'St. Pierre And Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Puerto Rico',
        'PS'=>'Palestine',
        'PT'=>'Portugal',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Qatar',
        'RE'=>'Reunion',
        'RO'=>'Romania',
        'RS'=>'Serbia',
        'RU'=>'Russian Federation',
        'RW'=>'Rwanda',
        'SA'=>'Saudi Arabia',
        'GB-SCT'=>'Scotland',
        'SB'=>'Solomon Islands',
        'SC'=>'Seychelles',
        'SS'=>'South Sudan',
        'SD'=>'Sudan',
        'SE'=>'Sweden',
        'SG'=>'Singapore',
        'SH'=>'St. Helena',
        'SI'=>'Slovenia',
        'SJ'=>'Svalbard And Jan Mayen Islands',
        'SK'=>'Slovakia (Slovak Republic)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somalia',
        'SR'=>'Suriname',
        'ST'=>'Sao Tome And Principe',
        'SU'=>'Soviet Union',
        'SV'=>'El Salvador',
        'SY'=>'Syrian Arab Republic',
        'SZ'=>'Swaziland',
        'TC'=>'Turks And Caicos Islands',
        'TD'=>'Chad',
        'TF'=>'French Southern Territories',
        'TG'=>'Togo',
        'TH'=>'Thailand',
        'TJ'=>'Tajikistan',
        'TK'=>'Tokelau',
        'TI'=>'East Timor',
        'TM'=>'Turkmenistan',
        'TN'=>'Tunisia',
        'TO'=>'Tonga',
        'TP'=>'East Timor (old code)',
        'TR'=>'Turkey',
        'TT'=>'Trinidad And Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Taiwan',
        'TZ'=>'Tanzania, United Republic Of',
        'UA'=>'Ukraine',
        'UG'=>'Uganda',
        'UK'=>'United Kingdom',
        'US'=>'United States',
        'UM'=>'United States Minor Outlying Islands',
        'UY'=>'Uruguay',
        'UZ'=>'Uzbekistan',
        'VA'=>'Vatican City State (Holy See)',
        'VC'=>'Saint Vincent And The Grenadines',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Islands (British)',
        'VI'=>'Virgin Islands (U.S.)',
        'VN'=>'Viet Nam',
        'VU'=>'Vanuatu',
        'GB-WLS' =>'Wales',
        'WF'=>'Wallis And Futuna Islands',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'South Africa',
        'ZM'=>'Zambia',
        'ZW'=>'Zimbabwe',
    ],
];
